ArxivLens
ArXiv cs.CV

LCM: Locally Constrained Compact Point Cloud Model for Masked Point Modeling

Bin Chen, Hang Guo, Naiqi Li, Shu-Tao Xia

2405.17149 Published May 28, 2024
Read paper View PDF
More tools
At a glance AI-generated · verify against the paper

The paper proposes a Locally Constrained Compact Point Cloud Model (LCM) to improve Masked Point Modeling (MPM) efficiency by replacing the Transformer's self-attention with locally constrained compact encoder and Mamba-based decoder, achieving better performance and efficiency. The LCM-based Point-MAE model notably outperforms Transformer-based models in performance and reduces parameters and computation significantly.

Abstract

The pre-trained point cloud model based on Masked Point Modeling (MPM) has exhibited substantial improvements across various tasks. However, these models heavily rely on the Transformer, leading to quadratic complexity and limited decoder, hindering their practice application. To address this limitation, we first conduct a comprehensive analysis of existing Transformer-based MPM, emphasizing the idea that redundancy reduction is crucial for point cloud analysis. To this end, we propose a Locally constrained Compact point cloud Model (LCM) consisting of a locally constrained compact encoder and a locally constrained Mamba-based decoder. Our encoder replaces self-attention with our local aggregation layers to achieve an elegant balance between performance and efficiency. Considering the varying information density between masked and unmasked patches in the decoder inputs of MPM, we introduce a locally constrained Mamba-based decoder. This decoder ensures linear complexity while maximizing the perception of point cloud geometry information from unmasked patches with higher information density. Extensive experimental results show that our compact model significantly surpasses existing Transformer-based models in both performance and efficiency, especially our LCM-based Point-MAE model, compared to the Transformer-based model, achieved an improvement of 2.24%, 0.87%, and 0.94% in performance on the three variants of ScanObjectNN while reducing parameters by 88% and computation by 73%.

AI Key Findings

Get AI-generated insights about this paper's methodology, results, significance, and more — available when analysis has been generated.

Paper preview View the original document Preview of the original paper

How to Cite This Paper

Reference manager: RIS EndNote

Discussion 0

This website uses cookies to ensure you get the best experience. Learn more